@@ -8,7 +8,7 @@
 #' @param its Number of iterations to use
 #' @param updatePrior Logical flag, defaults to \code{FAlSE}. Set whether the parameters of the base measure are updated.
 #' @param progressBar Logical flag indicating whether to display a progress bar.
-#' @return A Dirichlet Process object the fitted cluster parameters and labels.
+#' @return A Dirichlet Process object with the fitted cluster parameters and labels.
 #'
 #' @references Neal, R. M. (2000). Markov chain sampling methods for Dirichlet process mixture models. Journal of computational and graphical statistics, 9(2), 249-265.
 #'
@@ -16,7 +16,7 @@
 Fit <- function(dpObj, its, updatePrior = FALSE, progressBar=TRUE) UseMethod("Fit", dpObj)
 
 #' @export
-Fit.default <- function(dpObj, its, updatePrior = FALSE, progressBar=TRUE) {
+Fit.default <- function(dpObj, its, updatePrior = FALSE, progressBar = interactive()) {
 
   if (progressBar){
     pb <- txtProgressBar(min=0, max=its, width=50, char="-", style=3)
@@ -46,7 +46,7 @@ Fit.default <- function(dpObj, its, updatePrior = FALSE, progressBar=TRUE) {
 
     if (updatePrior) {
       dpObj$mixingDistribution <- PriorParametersUpdate(dpObj$mixingDistribution,
-        dpObj$clusterParameters)
+                                                        dpObj$clusterParameters)
     }
     if (progressBar){
       setTxtProgressBar(pb, i)
@@ -68,7 +68,7 @@ Fit.default <- function(dpObj, its, updatePrior = FALSE, progressBar=TRUE) {
 }
 
 #'@export
-Fit.hierarchical <- function(dpObj, its, updatePrior = FALSE, progressBar = TRUE){
+Fit.hierarchical <- function(dpObj, its, updatePrior = FALSE, progressBar = interactive()){
   if (progressBar) {
     pb <- txtProgressBar(min=0, max=its, width=50, char="-", style=3)
   }
@@ -110,4 +110,3 @@ Fit.hierarchical <- function(dpObj, its, updatePrior = FALSE, progressBar = TRUE
   return(dpObj)
 }
 
-
